Top 5 Unique Data
Top 5 Unique Pattern
Histogram
Boxplot
Metrics

Metrics | Value
--- | ---
distinct value | @distinct_value
min | @min_value
max | @max_value
mean | @mean
mode | @mode
median | @median
Variance | @variance
Standard deviation | @std

Metrics

Metrics | Value
--- | ---
median | @median
first quartile | @first_quartile
third_quartile | @third_quartile
iqr | @iqr
minimum | @minimum
maximum | @maximum
upper outliner datapoint | @negative_outliner_datapoint
lower outliner datapoint | @positive_outliner_datapoint